Interface: TooltipItem | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TooltipItem<TType>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`

## # Properties

### # chart

• chart: `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`>

The chart the tooltip is being shown on

#### # Defined in

index.esm.d.ts:2793
(opens new window)

### # dataIndex

• dataIndex: `number`

Index of this data item in the dataset

#### # Defined in

index.esm.d.ts:2828
(opens new window)

### # dataset

• dataset: `UnionToIntersection`<`ChartDataset`<`TType`, `DistributiveArray`<`ChartTypeRegistry`[`TType`][`"defaultDataPoint"`]>>>

The dataset the item comes from

#### # Defined in

index.esm.d.ts:2818
(opens new window)

### # datasetIndex

• datasetIndex: `number`

Index of the dataset the item comes from

#### # Defined in

index.esm.d.ts:2823
(opens new window)

### # element

• element: `Element`<`AnyObject`, `AnyObject`>

The chart element (point, arc, bar, etc.) for this tooltip item

#### # Defined in

index.esm.d.ts:2833
(opens new window)

### # formattedValue

• formattedValue: `string`

Formatted value for the tooltip

#### # Defined in

index.esm.d.ts:2813
(opens new window)

### # label

• label: `string`

Label for the tooltip

#### # Defined in

index.esm.d.ts:2798
(opens new window)

### # parsed

• parsed: `UnionToIntersection`<`ParsedDataType`<`TType`>>

Parsed data values for the given `dataIndex` and `datasetIndex`

#### # Defined in

index.esm.d.ts:2803
(opens new window)

### # raw

• raw: `unknown`

Raw data values for the given `dataIndex` and `datasetIndex`

#### # Defined in

index.esm.d.ts:2808
(opens new window)